<?php
/**
 * Webkul MarketingCloud Magento Connector SyncAllCustomer Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */
namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Customer;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;
use Magento\Customer\Model\ResourceModel\Customer\CollectionFactory;

class SyncAllCustomer extends \Magento\Backend\App\Action
{
        /**
         * @param Action\Context $context
         * @param Filter $filter
         * @param CollectionFactory $collectionFactory
         */
        protected $_collectionFactory;
        protected $_filter;
        protected $_scopeConfig;
        protected $_customer;
        protected $_customerFactory;

    public function __construct(
        Filter $filter,
        CollectionFactory $collectionFactory,
        \Magento\Customer\Model\Customer $customers,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Customer\Model\CustomerFactory $customerFactory,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory

    ) {
        parent::__construct($context);
        $this->_filter = $filter;
        $this->_customers = $customers;
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        $this->_customerFactory = $customerFactory;
        $this->_collectionFactory = $collectionFactory;
        $this->_resultForwardFactory = $resultForwardFactory;
    }

    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if(isset($token) && $token != null){
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            return $resultRedirect->setPath('adminhtml/system_config/edit/section/marketingcloudmagentoconnector');
        }
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        $limit = $this->_scopeConfig->getValue('marketingcloud/batch/mc_batch_customer') ?? '10';
        $exportIds = [];
        $helper = $this->_connection;
        $collection = $this->_customers->getCollection()->addAttributeToSelect("entity_id")->setPageSize($limit)->setCurPage(1);
        $res = $helper->getSyncCustomer($collection);
        $exportIds = $collection->getAllIds();

        if (count($collection) == 0) {
            $this->_messageManager->addSuccess(__("No Customers are exist at Magento."));
        } else {
            if (count($exportIds) == 0) {
                $this->_messageManager->addSuccess(__("All Magento Customers are exported Successfully!!"));
            }
            else{
                $this->_messageManager->addSuccess(__("All Magento Customers are exported Successfully!!"));
            }
        }

        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return  $resultRedirect->setPath('customer/index/index', ['store' => $storeId]);
    }
}
