<?php
/**
 * Webkul MarketingCloud Magento Connector SyncProduct Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */
namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Product;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;
use Magento\Catalog\Controller\Adminhtml\Product;
use Magento\Catalog\Model\ResourceModel\Product\CollectionFactory;

class SyncProduct extends \Magento\Catalog\Controller\Adminhtml\Product
{
        /**
         * @param Action\Context $context
         * @param Builder $productBuilder
         * @param \Magento\Catalog\Model\Indexer\Product\Price\Processor $productPriceIndexerProcessor
         * @param Filter $filter
         * @param CollectionFactory $collectionFactory
         */
    public function __construct(
        Filter $filter,
        Product\Builder $productBuilder,
        CollectionFactory $collectionFactory,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection
    ) {
        parent::__construct($context, $productBuilder);
        $this->_filter = $filter;
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        $this->_collectionFactory = $collectionFactory;
    }

    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if(isset($token) && $token != null){
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            return $resultRedirect->setPath('adminhtml/system_config/edit/section/marketingcloudmagentoconnector');
        }
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        $helper = $this->_connection;
        $helper->callMcMethod();
        $userId = $helper->getSession()->getUserId();

        $collection = $this->_filter->getCollection($this->_collectionFactory->create());
        $res = $helper->getSyncProduct($collection);

        if($res && $res[0]){
            $message = "Product Successfully Exported In DataExtension!!!";
            $this->_messageManager->addSuccess(__($message));
        } else{
            $this->_messageManager->addSuccess(__("All Magento Products are exported Successfully!!"));
        }
        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return  $resultRedirect->setPath('catalog/*/', ['store' => $storeId]);
    }
}
